import click
from click_help_colors import HelpColorsCommand

import stf.common.config as common_config
import stf.common.filesystem as common_filesystem
import stf.common.docker as common_docker
import os
import sys
import shutil

sys.path.insert(1, os.getcwd())


@click.command(
    cls=HelpColorsCommand,
    help_headers_color='yellow',
    help_options_color='green',
)
def init():
    click.secho("Initializing project config", fg='blue')

    base_project_config_file = "%s/config.base.yml" % (common_config.get_assets_dir())
    target = "%s/config.yml" % os.getcwd()

    shutil.copyfile(base_project_config_file, target)



from stf.test_case.magento import MagentoTestCase


class TestCase(MagentoTestCase):

    def test_success_sample(self):
        try:
            self.assertTrue(True)
        except AssertionError as e:
            raise AssertionError(self.generateExceptionReport(e))

    def test_fail_sample(self):
        try:
            self.assertTrue(False)
        except AssertionError as e:
            raise AssertionError(self.generateExceptionReport(e))


import os
import shutil
from .config import tests_folder


def create_test_folder():
    path = os.getcwd() + '/' + tests_folder
    try:
        os.mkdir(path)
        init_file_path = "%s/__init__.py" % path
        with open(init_file_path, 'w') as fp:
            pass

    except OSError as e:
        if e.errno == 17:  # Folder already exists
            return False
        else:
            raise Exception(e)

    return True


def copy_sample_test(name, type):
    original = os.path.dirname(__file__) + '/../test_case/sample/' + type + '.py'
    target = os.getcwd() + '/' + tests_folder + '/' + name + '.py'

    shutil.copyfile(original, target)

    return target



import click
from click_help_colors import HelpColorsGroup
import os
import sys

sys.path.append(os.getcwd())

from stf.command import config as config_commands
from stf.command import grid as grid_commands
from stf.command import suite as suite_commands


@click.group(
    cls=HelpColorsGroup,
    help_headers_color='yellow',
    help_options_color='green',
)
@click.version_option()
def cli():
    pass


cli.add_command(config_commands.init, 'config:init')
cli.add_command(grid_commands.init, 'grid:init')
cli.add_command(suite_commands.create, 'suite:create')
cli.add_command(suite_commands.run, 'suite:run')



from .base import BaseTestCase

from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC


class MagentoTestCase(BaseTestCase):
    def visit_product_page(self, sku):
        driver = self.driver
        wait = WebDriverWait(driver, self.config['time_to_sleep'])

        search_input = wait.until(EC.element_to_be_clickable((By.XPATH, "//input[@id='search']")))
        search_input.send_keys(sku)
        search_input.submit()
        pdp = wait.until(EC.visibility_of_element_located((By.XPATH, "//div[@class='product-info-main']")))

        return pdp

    def checkout_loader(self):
        driver = self.driver
        # function wait for checkout loader
        wait = WebDriverWait(driver, self.config['time_to_sleep'])
        loading = wait.until(EC.invisibility_of_element_located((By.XPATH, "//div[@class='loading-mask']")))

        return loading

    def login_page(self):
        driver = self.driver
        # function to go to login page
        wait = WebDriverWait(driver, self.config['time_to_sleep'])
        loading = wait.until(EC.invisibility_of_element_located((By.XPATH, "//div[@class='loading-mask']")))
        loginBtn = wait.until(EC.element_to_be_clickable((By.XPATH, "//div[@id='header-my-account']")))
        loginBtn.click()

    def login(self, username, password):
        driver = self.driver
        # function to fill login form
        wait = WebDriverWait(driver, self.config['time_to_sleep'])
        login_form = wait.until(EC.visibility_of_element_located((By.XPATH, "//form[@id='login-form']")))
        email_field = driver.find_element_by_xpath("//input[@id='customer-email']")
        password_field = driver.find_element_by_xpath("//input[@id='pass']")
        email_field.send_keys(username)
        password_field.send_keys(password)
        password_field.submit()


import click
from click_help_colors import HelpColorsCommand

import stf.common.config as common_config
import stf.common.filesystem as common_filesystem
import stf.common.docker as common_docker
import os
import sys
import yaml

sys.path.insert(1, os.getcwd())


@click.command(
    cls=HelpColorsCommand,
    help_headers_color='yellow',
    help_options_color='green',
)
@click.option('-m', '--mode', 'mode', required=False, default="normal", type=click.Choice(['normal', 'debug']))
def init(mode):
    click.secho("Initializing docker for selenium in %s mode" % (mode), fg='blue')

    base_docker_compose_file = "%s/docker-compose.base.yml" % (common_config.get_assets_dir())
    with open(base_docker_compose_file, 'r') as ymlfile:
        docker_compose = yaml.full_load(ymlfile)

        if mode == common_docker.DOCKER_MODE_DEBUG:
            docker_compose['services']['selenium-hub']['environment'].extend([
                'GRID_DEBUG=true',
                'SE_OPTS="-debug"'
            ])

        docker_compose['services']['chrome'] = common_docker.get_chrome_config(mode)
        docker_compose['services']['firefox'] = common_docker.get_firefox_config(mode)

        output_docker_file = "%s/docker-compose.yml" % (os.getcwd())
        with open(output_docker_file, 'w') as file:
            yaml.dump(docker_compose, file, default_flow_style=False, canonical=False, indent=2)



import stf.common.config as common_config
import unittest
import os


class TestCommonConfigGetConfig(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.current_dir = os.path.dirname(os.path.realpath(__file__)) + '/fixtures'

    def test_non_existent_file(self):
        config_file = 'non_existent_file.yml'
        with self.assertRaises(FileNotFoundError):
            common_config.get_config(self.current_dir, config_file)

    def test_empty_file(self):
        config_file = 'empty_config_file.yml'
        config = common_config.get_config(self.current_dir, config_file)
        self.assertIsNone(config)

    def test_basic_file(self):
        config_file = 'basic_config_file.yml'
        actual = common_config.get_config(self.current_dir, config_file)
        expected = {
            'dev': {
                'url': 'https://example.com/'
            }
        }
        self.assertEqual(expected, actual)


class TestCommonConfigIsValid(unittest.TestCase):
    def test_empty_config(self):
        config = None
        actual = common_config.is_valid(config)
        self.assertFalse(actual)

    def test_only_one_empty_environment(self):
        config = {
            'dev': None
        }
        actual = common_config.is_valid(config)
        self.assertFalse(actual)


class TestCommonConfigGetSampleBaseDir(unittest.TestCase):
    def test_get_base_dir(self):
        expected = os.path.abspath(os.path.dirname(__file__) + '/../test_case/sample/')
        actual = common_config.get_sample_base_dir()
        self.assertEqual(expected, actual)


from stf.test_case.magento import BaseTestCase


class TestCase(BaseTestCase):

    def test_fail(self):
        try:
            self.assertTrue(False)
        except AssertionError as e:
            raise AssertionError(self.generateExceptionReport(e))

    def test_create_new_customer(self):
        pass



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

def local_scheme(version):
    return ""

setuptools.setup(
    name='summa-testing-framework-summasolutions',
    # version='0.1.16',
    author='Summa Solutions',
    author_email='coreteam@summasoutions.net',
    description='Summa Solutions Testing Framework',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://bitbucket.org/summasolutions/summa-testing-framework",
    py_modules=['stf'],
    use_scm_version={
        "local_scheme": local_scheme,
    },
    setup_requires=['setuptools_scm'],
    install_requires=[
        'Click',
        'click_help_colors',
        'colorama',
        'pyunitreport',
        'PyYAML',
        'selenium'
    ],
    packages=setuptools.find_packages(),
    include_package_data=True,
    entry_points='''
        [console_scripts]
        stf=stf.cli:cli
    ''',
    python_requires='>=3.6',
)
